aboutsummaryrefslogtreecommitdiff
path: root/engine/lib/navigation.php
diff options
context:
space:
mode:
authorMatt Beckett <beck24@gmail.com>2012-07-17 22:39:49 -0600
committerMatt Beckett <beck24@gmail.com>2012-07-17 22:39:49 -0600
commitb336f1065259b28113be1bca11dabe3ac167bd1a (patch)
treec2bfbef0e80f23c1ffbb8059738bef4609349c73 /engine/lib/navigation.php
parentb134c8c70cc310e8170da44d1e2291f507cb31ff (diff)
downloadelgg-b336f1065259b28113be1bca11dabe3ac167bd1a.tar.gz
elgg-b336f1065259b28113be1bca11dabe3ac167bd1a.tar.bz2
switched to matching by link name - same results, simpler code
Diffstat (limited to 'engine/lib/navigation.php')
-rw-r--r--engine/lib/navigation.php15
1 files changed, 3 insertions, 12 deletions
diff --git a/engine/lib/navigation.php b/engine/lib/navigation.php
index 8845d5164..a9d28e22e 100644
--- a/engine/lib/navigation.php
+++ b/engine/lib/navigation.php
@@ -321,21 +321,12 @@ function elgg_site_menu_setup($hook, $type, $return, $params) {
}
if (!$selected) {
- // nothing selected, match by handler
- $handler = get_input('handler');
-
+ // nothing selected, match name to context
foreach ($return as $section_name => $section) {
foreach ($section as $key => $item) {
- // determine the 'handler' of this url, if there is one
+ // only highlight internal links
if (strpos($item->getHref(), elgg_get_site_url()) === 0) {
- // this is an internal link, so it has a page handler
- $path = array(str_replace(elgg_get_site_url(), '', $item->getHref()));
- $separators = array('/', '?', '#');
- foreach ($separators as $separator) {
- $path = explode($separator, $path[0]);
- }
-
- if ($path[0] == $handler) {
+ if ($item->getName() == elgg_get_context()) {
$return[$section_name][$key]->setSelected(true);
break 2;
}